@@ -286,8 +286,8 @@ float SnnsCLib::cc_getErr (int StartPattern, int EndPattern)
 {
     int p=0, sub, start, end, n,  pat, dummy;
     float sse=0, devit,error;
-    register Patterns out_pat;
-    register struct Unit *OutputUnitPtr;
+    Patterns out_pat;
+    struct Unit *OutputUnitPtr;
     //int Correct;
     //int WhichWin,CorrWin;
     float MaxAct;
@@ -314,7 +314,7 @@ float SnnsCLib::cc_getErr (int StartPattern, int EndPattern)
 		MaxAct=OutputUnitPtr->Out.output;
 		//WhichWin=dummy;
 	    }
-	    //if (abs(devit) > 0.2) Correct=FALSE;
+	    //if (fabs(devit) > 0.2) Correct=FALSE;
 	    sse += devit*devit;
 	    error = devit * 
 		((this->*OutputUnitPtr->act_deriv_func)(OutputUnitPtr) + cc_fse);
@@ -1059,7 +1059,7 @@ krui_err SnnsCLib::cc_topoSort(int topoSortID)
 ******************************************************************************/
 krui_err SnnsCLib::cc_topoSortMain(int topoSortId)
 {
-    register struct Unit   *unit_ptr;
+    struct Unit   *unit_ptr;
     int   io_units,h,counter=0;
   
     KernelErrorCode = KRERR_NO_ERROR;  /*  reset return code  */
