@@ -265,9 +265,9 @@ krui_err SnnsCLib::pr_calcMeanDeviation (int pattern, float *sum_error)
 
 {
 
-    register struct Unit *unit_ptr;
-    register TopoPtrArray topo_ptr;
-    register Patterns out_pat;
+    struct Unit *unit_ptr;
+    TopoPtrArray topo_ptr;
+    Patterns out_pat;
     int size, pattern_no, sub_pat_no, no_of_patterns;
     
     /* initialize sum error */
@@ -343,12 +343,12 @@ krui_err SnnsCLib::pr_calcMeanDeviation (int pattern, float *sum_error)
 {
 
     if ((pr_candidateLink == NULL) ||
-	(abs (link_ptr->weight) < pr_candidateSaliency))
+	(fabs (link_ptr->weight) < pr_candidateSaliency))
 	/* found first or least important link so far */
     {
 	pr_candidateTargetUnit = unit_ptr;
 	pr_candidateLink = link_ptr;
-	pr_candidateSaliency = abs (link_ptr->weight);
+	pr_candidateSaliency = fabs (link_ptr->weight);
     }
 
 }
@@ -373,9 +373,9 @@ krui_err SnnsCLib::PRUNE_Mag (int pattern)
 
 {
 
-    register struct Unit *unit_ptr;
-    register struct Site *site_ptr;
-    register struct Link *link_ptr;
+    struct Unit *unit_ptr;
+    struct Site *site_ptr;
+    struct Link *link_ptr;
 
     FOR_ALL_UNITS (unit_ptr)
 	/* process links to all units */
@@ -473,12 +473,12 @@ krui_err SnnsCLib::PRUNE_OBD (int pattern)
 
 {
 
-    register struct Unit *unit_ptr;
-    register struct Site *site_ptr;
-    register struct Link *link_ptr;
-    register TopoPtrArray topo_ptr;
-    register Patterns out_pat;
-    register float deriv, delta, delta2, devit;
+    struct Unit *unit_ptr;
+    struct Site *site_ptr;
+    struct Link *link_ptr;
+    TopoPtrArray topo_ptr;
+    Patterns out_pat;
+    float deriv, delta, delta2, devit;
     int size, pattern_no, sub_pat_no;
 
     /* reset auxiliary variables in unit array */
@@ -621,9 +621,9 @@ void SnnsCLib::pr_obs_setInitParameter (float param)
 
 {
 
-    register struct Unit *unit_ptr;
-    register struct Site *site_ptr;
-    register struct Link *link_ptr;
+    struct Unit *unit_ptr;
+    struct Site *site_ptr;
+    struct Link *link_ptr;
 
     /* initialize global variable */
     pr_noOfLinks = 0;
@@ -681,10 +681,10 @@ void SnnsCLib::pr_obs_setInitParameter (float param)
 
 {
 
-    register struct Unit *unit_ptr;
-    register struct Site *site_ptr;
-    register struct Link *link_ptr;
-    register TopoPtrArray topo_ptr;
+    struct Unit *unit_ptr;
+    struct Site *site_ptr;
+    struct Link *link_ptr;
+    TopoPtrArray topo_ptr;
     float help;
     int weight_no = 0;
 
@@ -704,12 +704,12 @@ void SnnsCLib::pr_obs_setInitParameter (float param)
 	    else
 		help = 0;
 
-	    if (UNIT_HAS_DIRECT_INPUTS (unit_ptr))
+	    if (UNIT_HAS_DIRECT_INPUTS (unit_ptr)) {
 		FOR_ALL_LINKS (unit_ptr, link_ptr)
 		    if (!IS_SPECIAL_UNIT (link_ptr->to))
 			/* calculate derivative and propagate information back */
 			pr_obs_calculateDerivative (link_ptr, help, weight_no++);
-	    else
+            }  else
 		FOR_ALL_SITES_AND_LINKS (unit_ptr, site_ptr, link_ptr)
 		    if (!IS_SPECIAL_UNIT (link_ptr->to))
 			/* calculate derivative and propagate information back */
@@ -724,12 +724,12 @@ void SnnsCLib::pr_obs_setInitParameter (float param)
 	{
 	    help = (this->*unit_ptr->act_deriv_func) (unit_ptr) *
 		unit_ptr->value_a;
-	    if (UNIT_HAS_DIRECT_INPUTS (unit_ptr))
+	    if (UNIT_HAS_DIRECT_INPUTS (unit_ptr)) {
 		FOR_ALL_LINKS (unit_ptr, link_ptr)
 		    if (!IS_SPECIAL_UNIT (link_ptr->to))
 			/* calculate derivative and propagate information back */
 			pr_obs_calculateDerivative (link_ptr, help, weight_no++);
-	    else
+            }  else
 		FOR_ALL_SITES_AND_LINKS (unit_ptr, site_ptr, link_ptr)
 		    if (!IS_SPECIAL_UNIT (link_ptr->to))
 			/* calculate derivative and propagate information back */
@@ -807,8 +807,8 @@ void SnnsCLib::pr_obs_setInitParameter (float param)
 
 {
 
-    register struct Unit *unit_ptr;
-    register TopoPtrArray topo_ptr;
+    struct Unit *unit_ptr;
+    TopoPtrArray topo_ptr;
     int no_of_patterns, pattern_no, sub_pat_no, i;
 
     /* initialize matrix */
@@ -932,10 +932,10 @@ void SnnsCLib::pr_obs_setInitParameter (float param)
 krui_err SnnsCLib::PRUNE_OBS (int pattern)
 {
 
-    register struct Unit *unit_ptr;
-    register struct Site *site_ptr;
-    register struct Link *link_ptr;
-    register TopoPtrArray topo_ptr;
+    struct Unit *unit_ptr;
+    struct Site *site_ptr;
+    struct Link *link_ptr;
+    TopoPtrArray topo_ptr;
     float update_const;
     int err, link_no;
 
@@ -986,33 +986,35 @@ krui_err SnnsCLib::PRUNE_OBS (int pattern)
 	 unit_ptr != NULL;
 	 unit_ptr = *(topo_ptr--))
 	/* process links to all output units */
-	if (!IS_SPECIAL_UNIT (unit_ptr))
-	    if UNIT_HAS_DIRECT_INPUTS (unit_ptr)
+	if (!IS_SPECIAL_UNIT (unit_ptr)) {
+	    if UNIT_HAS_DIRECT_INPUTS (unit_ptr) {
 		/* unit has direct inputs */
 		FOR_ALL_LINKS (unit_ptr, link_ptr)
 		    if (!IS_SPECIAL_UNIT (link_ptr->to))
 			pr_obs_processLink (unit_ptr, link_ptr, link_no++);
-	    else
+	    }  else
 		/* unit has sites */
 		FOR_ALL_SITES_AND_LINKS (unit_ptr, site_ptr, link_ptr)
 		    if (!IS_SPECIAL_UNIT (link_ptr->to))
 			pr_obs_processLink (unit_ptr, link_ptr, link_no++);
+        }
 
     for (unit_ptr = *(topo_ptr--);
 	 unit_ptr != NULL;
 	 unit_ptr = *(topo_ptr--))
 	/* process links to all hidden units */
-	if (!IS_SPECIAL_UNIT (unit_ptr))
-	    if UNIT_HAS_DIRECT_INPUTS (unit_ptr)
+	if (!IS_SPECIAL_UNIT (unit_ptr)) {
+	    if UNIT_HAS_DIRECT_INPUTS (unit_ptr) {
 		/* unit has direct inputs */
 		FOR_ALL_LINKS (unit_ptr, link_ptr)
 		    if (!IS_SPECIAL_UNIT (link_ptr->to))
 			pr_obs_processLink (unit_ptr, link_ptr, link_no++);
-	    else
+	    }  else
 		/* unit has sites */
 		FOR_ALL_SITES_AND_LINKS (unit_ptr, site_ptr, link_ptr)
 		    if (!IS_SPECIAL_UNIT (link_ptr->to))
 			pr_obs_processLink (unit_ptr, link_ptr, link_no++);
+        }
 
     /* calculate auxiliary variable for efficient update of weights */
     update_const = pr_candidateLink->weight /
@@ -1026,33 +1028,35 @@ krui_err SnnsCLib::PRUNE_OBS (int pattern)
 	 unit_ptr != NULL;
 	 unit_ptr = *(topo_ptr--))
 	/* process links to all output units */
-	if (!IS_SPECIAL_UNIT (unit_ptr))
-	    if UNIT_HAS_DIRECT_INPUTS (unit_ptr)
+	if (!IS_SPECIAL_UNIT (unit_ptr)) {
+	    if UNIT_HAS_DIRECT_INPUTS (unit_ptr) {
 		/* unit has direct inputs */
 		FOR_ALL_LINKS (unit_ptr, link_ptr)
 		    if (!IS_SPECIAL_UNIT (link_ptr->to))
 			pr_obs_updateLink (link_ptr, update_const, link_no++);
-	    else
+	    }  else
 		/* unit has sites */
 		FOR_ALL_SITES_AND_LINKS (unit_ptr, site_ptr, link_ptr)
 		    if (!IS_SPECIAL_UNIT (link_ptr->to))
 			pr_obs_updateLink (link_ptr, update_const, link_no++);
+        }
 
     for (unit_ptr = *(topo_ptr--);
 	 unit_ptr != NULL;
 	 unit_ptr = *(topo_ptr--))
 	/* process links to all hidden units */
-	if (!IS_SPECIAL_UNIT (unit_ptr))
-	    if UNIT_HAS_DIRECT_INPUTS (unit_ptr)
+	if (!IS_SPECIAL_UNIT (unit_ptr)) {
+	    if UNIT_HAS_DIRECT_INPUTS (unit_ptr) {
 		/* unit has direct inputs */
 		FOR_ALL_LINKS (unit_ptr, link_ptr)
 		    if (!IS_SPECIAL_UNIT (link_ptr->to))
 			pr_obs_updateLink (link_ptr, update_const, link_no++);
-	    else
+	    }  else
 		/* unit has sites */
 		FOR_ALL_SITES_AND_LINKS (unit_ptr, site_ptr, link_ptr)
 		    if (!IS_SPECIAL_UNIT (link_ptr->to))
 			pr_obs_updateLink (link_ptr, update_const, link_no++);
+        }
 
     /* free matrixes */
     RbfFreeMatrix (&pr_inverseHessian);
@@ -1138,13 +1142,13 @@ krui_err SnnsCLib::PRUNE_Skeletonization (int pattern)
 
 {
 
-    register struct Unit *unit_ptr;
-    register struct Site *site_ptr;
-    register struct Link *link_ptr;
-    register TopoPtrArray topo_ptr;
+    struct Unit *unit_ptr;
+    struct Site *site_ptr;
+    struct Link *link_ptr;
+    TopoPtrArray topo_ptr;
     //static bool PRUNE_Skeletonization_first = TRUE;
 
-    register Patterns out_pat;
+    Patterns out_pat;
     int size, pattern_no, sub_pat_no;//, no_of_patterns;
 
     if (PRUNE_Skeletonization_first){
